| R Documentation |
Given the output of extRC function, it is written in a readable form.
## S3 method for class 'extRC'
print(x, ...)
x |
output from |
... |
further arguments passed to or from other methods |
None |
Francesco Bartolucci, Antonio Forcina
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.